@@ -33,7 +33,7 @@ ngettext = gettext.ngettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/aleiva/work/gnome/orca-master/bld", "share", "locale")
+localedir = os.path.join ("/home/aleiva/work/gnome/orca-new-release/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
